==> percona-xtrabackup-8.0.30-23.tar.gz: percona-xtrabackup-8.0.30-23/README.md <==
## Percona XtraBackup

![PXB logo](storage/innobase/xtrabackup/doc/source/percona-xtrabackup-logo.jpg)

Percona XtraBackup is an open-source hot backup utility for MySQL - based servers that doesn’t lock your database during the backup.

Whether it is a 24x7 highly loaded server or a low-transaction-volume environment, Percona XtraBackup is designed to make backups a seamless procedure without disrupting the performance of the server in a production environment. Commercial support contracts are available.

Percona XtraBackup 8.0 can back up data from InnoDB, XtraDB, MyISAM, and MyRocks tables on MySQL 8.0 servers as well as Percona Server for MySQL with XtraDB, Percona Server for MySQL 8.0, and Percona XtraDB Cluster 8.0. 

Percona XtraBackup 2.4 can back up data from InnoDB, XtraDB, and MyISAM tables on MySQL 5.7 servers, as well as Percona Server for MySQL with XtraDB.

For more information about the Percona XtraBackup components and how to use this product, see the [Percona XtraBackup documentation](https://www.percona.com/doc/percona-xtrabackup).

## Installation

You can install Percona XtraBackup using the following methods:
- from the Percona repository 
- Build from the [source code](https://github.com/percona/percona-xtrabackup)

The installation instructions in the official documentation are [here](https://www.percona.com/doc/percona-xtrabackup/8.0/installation.html).

## Submit a bug report or a feature request

If you find a bug in Percona XtraBackup, you can submit a report to the project's [Jira issue tracker](https://jira.percona.com/projects/PXB/issues)

As a general rule of thumb, please try to create a bug report that is:

- Reproducible - include the steps on how to reproduce the issue
- Specific - include as much detail as possible, such as which version, which environment, etc.
- Unique - do not duplicate existing tickets
- Scoped to a single issue - only one issue per report

## Licensing

Percona is dedicated to **keeping open source open**. Whenever possible, we strive to include permissive licensing for both our software and documentation. For this project, we are using version 2 of the GNU General Public License (GPLv2).

## How to get involved

We encourage contributions and are always looking for new members that are as dedicated to serving the community as we are. The [Contributing Guide](https://github.com/percona/percona-xtrabackup/blob/8.0/storage/innobase/xtrabackup/doc/source/contributing.md) contains how you can contribute.

## Contact

You can reach us by using the [Forum](https://forums.percona.com/c/mysql-mariadb/percona-xtrabackup).

==> percona-xtrabackup_8.4.0-5.orig.tar.gz: percona-xtrabackup-8.4.0-5/README.md <==

## Percona XtraBackup

![PXB logo](storage/innobase/xtrabackup/doc/source/percona-xtrabackup-logo.jpg)

Percona XtraBackup is an open-source hot backup utility for MySQL - based servers that doesn’t lock your database during the backup.

Whether it is a 24x7 highly loaded server or a low-transaction-volume environment, Percona XtraBackup is designed to make backups a seamless procedure without disrupting the performance of the server in a production environment. Commercial support contracts are available.

Percona XtraBackup 8.0 can back up data from InnoDB, XtraDB, MyISAM, and MyRocks tables on MySQL 8.0 servers as well as Percona Server for MySQL with XtraDB, Percona Server for MySQL 8.0, and Percona XtraDB Cluster 8.0. 

Percona XtraBackup 2.4 can back up data from InnoDB, XtraDB, and MyISAM tables on MySQL 5.7 servers, as well as Percona Server for MySQL with XtraDB.

For more information about the Percona XtraBackup components and how to use this product, see the [Percona XtraBackup documentation](https://docs.percona.com/percona-xtrabackup/8.0/).

## Installation

You can install Percona XtraBackup using the following methods:
- Use the [Percona repository](https://docs.percona.com/percona-software-repositories/index.html) 
- Build from the [source code](https://github.com/percona/percona-xtrabackup)

The installation instructions in the official documentation are [here](https://docs.percona.com/percona-xtrabackup/8.0/installation.html).

## Submit a bug report or a feature request

If you find a bug in Percona XtraBackup, you can submit a report to the project's [Jira issue tracker](https://jira.percona.com/projects/PXB/issues)

As a general rule of thumb, please try to create a bug report that is:

- Reproducible - include the steps on how to reproduce the issue
- Specific - include as much detail as possible, such as which version, which environment, etc.
- Unique - do not duplicate existing tickets
- Scoped to a single issue - only one issue per report

## Licensing

Percona is dedicated to **keeping open source open**. Whenever possible, we strive to include permissive licensing for both our software and documentation. For this project, we are using version 2 of the GNU General Public License (GPLv2). For the documentation, we use [this license](https://docs.percona.com/percona-xtrabackup/8.0/copyright-and-licensing-information.html).

## How to get involved

We encourage contributions and are always looking for members that are as dedicated to serving the community as we are. The [Contributing Guide](https://github.com/percona/pxb-docs/blob/8.0/contributing.md) contains how you can contribute.

## Contact

You can reach us by using the [Forum](https://forums.percona.com/c/mysql-mariadb/percona-xtrabackup).
